<?php

/**
 * @file
 *   Configuratin settings for "Super SLide" module.
 */

/**
 * Menu callback 1 for admin settings.
 */
function super_slide_admin_settings1() {

  $form['super_slide_autodownload_plugins'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow automatic download of the latest version of the Cycle plugin and the jQuery plugin it depends on.'),
    '#default_value' => variable_get('super_slide_autodownload_plugins', TRUE),
    '#description' => t('If ticked you do not have to download Cycle and jQuery plugins yourself. This may incur a small performance penalty. Alternatively untick and follow the instructions that appear after you have configured your first slideshow.')
  );
  return system_settings_form($form);
}

/**
 * Menu callback 2 for admin settings.
 */
function super_slide_admin_settings2() {
  $max_shows = variable_get('super_slide_max_shows', 1);
  $form['super_slide_max_shows'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum number of slideshows you want on this site.'),
    '#default_value' => $max_shows,
    '#description' => t('If you increase this number, press "Save configuration" before filling out the rest of the form. You may change this number at any time.')
  );
  for ($show_no = 1; $show_no <= $max_shows; $show_no++) {
    $form["_configuration_$show_no"] = array(
      '#type' => 'fieldset',
      '#collapsible' => TRUE,
      '#title' => t('Slideshow #%show_no', array('%show_no' => $show_no)),
      '#description' => t('Specify page, slideshow container element and slide transition effect for slideshow #%show_no', array('%show_no' => $show_no))
    );
    $page_path = trim(variable_get("super_slide_path_$show_no", ''));
    $form["super_slide_configuration_$show_no"]["super_slide_path_$show_no"] = array(
      '#type' => 'textfield',
      '#title' => t('Page where slideshow #%show_no resides', array('%show_no' => $show_no)),
      '#default_value' => $page_path,
      '#description' => t('You may use path aliases. You can leave this field blank as the field below already defines the slideshow element. However, leaving the field blank is inefficient and may cause interference on pages where no slideshows are required.')
    );
    $container_id = trim(variable_get("super_slide_container_id_$show_no", ''));
    $form["super_slide_configuration_$show_no"]["super_slide_container_id_$show_no"] = array(
      '#type' => 'textfield',
      '#title' => t('Mandatory. Specifier for the HTML element that contains the images for slideshow #%show_no', array('%show_no' => $show_no)),
      '#default_value' => $container_id,
      '#description' => t('Use the CSS/jQuery format, e.g. the id of the HTML element (usually a &lt;div&gt;) that "wraps" the images for slideshow #%show_no',
        array('%show_no' => $show_no))
    );
    $effect_string = variable_get("super_slide_effect_string_$show_no", '');
    $form["super_slide_configuration_$show_no"]["super_slide_effect_string_$show_no"] = array(
      '#type' => 'textfield',
      '#title' => t('Slide transition effect for slideshow #%show_no', array('%show_no' => $show_no)),
      '#default_value' => $effect_string,
      '#description' => t('This can be either an effect name, like "turnRight", or a string enclosed in { } that specifies additional effect parameters. See !url for examples. Leave blank for "fade".',
        array('!url' => l(t('http://malsup.com/jquery/cycle/begin.html'), 'http://malsup.com/jquery/cycle/begin.html', array('attributes' => array('target' => '_blank')))
      ))
    );
  }
  return system_settings_form($form);
}
